==> RSurvey_0.6-4.tar.gz: RSurvey/inst/images/README.md <==
Images
======

Image files in this directory are covered by the following public licenses:

[gpl]: http://www.gnu.org/copyleft/gpl.html "GPL"
[lgpl]: http://www.gnu.org/licenses/lgpl.html "LGPL"
[cc]: http://creativecommons.org/licenses/by-nc/3.0 "Creative Commons"

- - -

**Images:** axes.gif, polygon.gif, transect.gif  
**Designer:** Jason C. Fisher  
**License:** GNU General Public License ([GPL][gpl])

- - -

**Images:** config.gif, new.gif, save.gif, saveas.gif  
**Icon set:** Crystal Clear  
**Designer:** Everaldo Coelho  
**Site:** <http://www.everaldo.com>  
**Contact:** <everaldo@everaldo.com></code>  
**License:** GNU Lesser General Public License ([LGPL][lgpl])


- - -

**Images:** globe.gif, import.gif  
**Designer:** David Vignoni  
**Icon set:** Nuvola  
**Site:** <http://www.icon-king.com>  
**Contact:** <info@icon-king.com></code>  
**License:** [LGPL][lgpl]

- - -

**Image:** close.gif  
**Icon set:** Glaze  
**Designer:** Marco Martin  
**Site:** <http://www.notmart.org>  
**Contact:** <mart@notmart.org></code>  
**License:** [LGPL][lgpl]

- - -

**Image:** help.gif  
**Icon set:** Futurosoft  
**Designer:** Sergio Sanchez Lopez  
**Site:** http://www.futurosoft.es  
**Contact:** <sergio9087@hotmail.com></code>  
**License:** [GPL][gpl]

- - -

**Image:** refresh.gif (remixed)  
**Icon set:** Minimal perception  
**Designer:** Mandarancio  
**Site:** <http://mandarancio.deviantart.com>  
**Contact:** <manda.mgf@gmail.com></code>  
**License:** Creative Commons ([Attribution-Noncommercial 3.0 Unported][cc])

- - -

**Image:** data.gif (remixed)  
**Icon set:** Gnome icons  
**Designer:** Gnome Project  
**Site:** <http://art.gnome.org/themes/icon>  
**License:** [GPL][gpl]

==> RSurvey_0.6-7.tar.gz: RSurvey/inst/images/README.md <==
Images
======

Image files in this directory are covered by the following public licenses:

[gpl]: http://www.gnu.org/copyleft/gpl.html "GPL"
[lgpl]: http://www.gnu.org/licenses/lgpl.html "LGPL"
[cc]: http://creativecommons.org/licenses/by-nc/3.0 "Creative Commons"

- - -

**Images:** axes.gif, polygon.gif, transect.gif, pch.gif, col.gif  
**Designer:** Jason C. Fisher  
**License:** GNU General Public License ([GPL][gpl])

- - -

**Images:** config.gif, new.gif, save.gif, saveas.gif  
**Icon set:** Crystal Clear  
**Designer:** Everaldo Coelho  
**Site:** <http://www.everaldo.com>  
**Contact:** <everaldo@everaldo.com></code>  
**License:** GNU Lesser General Public License ([LGPL][lgpl])


- - -

**Images:** globe.gif, import.gif  
**Designer:** David Vignoni  
**Icon set:** Nuvola  
**Site:** <http://www.icon-king.com>  
**Contact:** <info@icon-king.com></code>  
**License:** [LGPL][lgpl]

- - -

**Image:** close.gif  
**Icon set:** Glaze  
**Designer:** Marco Martin  
**Site:** <http://www.notmart.org>  
**Contact:** <mart@notmart.org></code>  
**License:** [LGPL][lgpl]

- - -

**Image:** help.gif  
**Icon set:** Futurosoft  
**Designer:** Sergio Sanchez Lopez  
**Site:** http://www.futurosoft.es  
**Contact:** <sergio9087@hotmail.com></code>  
**License:** [GPL][gpl]

- - -

**Image:** refresh.gif (remixed)  
**Icon set:** Minimal perception  
**Designer:** Mandarancio  
**Site:** <http://mandarancio.deviantart.com>  
**Contact:** <manda.mgf@gmail.com></code>  
**License:** Creative Commons ([Attribution-Noncommercial 3.0 Unported][cc])

- - -

**Image:** data.gif (remixed)  
**Icon set:** Gnome icons  
**Designer:** Gnome Project  
**Site:** <http://art.gnome.org/themes/icon>  
**License:** [GPL][gpl]
